@@ -13,30 +13,35 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.gkehub_v1 import gapic_version as package_version
+
+__version__ = package_version.__version__
 
 
-from .types.configmanagement import ConfigSync
-from .types.configmanagement import ConfigSyncDeploymentState
-from .types.configmanagement import ConfigSyncState
-from .types.configmanagement import ConfigSyncVersion
-from .types.configmanagement import ErrorResource
-from .types.configmanagement import GatekeeperDeploymentState
-from .types.configmanagement import GitConfig
-from .types.configmanagement import GroupVersionKind
-from .types.configmanagement import HierarchyControllerConfig
-from .types.configmanagement import HierarchyControllerDeploymentState
-from .types.configmanagement import HierarchyControllerState
-from .types.configmanagement import HierarchyControllerVersion
-from .types.configmanagement import InstallError
-from .types.configmanagement import MembershipSpec
-from .types.configmanagement import MembershipState
-from .types.configmanagement import OperatorState
-from .types.configmanagement import PolicyController
-from .types.configmanagement import PolicyControllerState
-from .types.configmanagement import PolicyControllerVersion
-from .types.configmanagement import SyncError
-from .types.configmanagement import SyncState
-from .types.configmanagement import DeploymentState
+from .types.configmanagement import (
+    ConfigSync,
+    ConfigSyncDeploymentState,
+    ConfigSyncState,
+    ConfigSyncVersion,
+    DeploymentState,
+    ErrorResource,
+    GatekeeperDeploymentState,
+    GitConfig,
+    GroupVersionKind,
+    HierarchyControllerConfig,
+    HierarchyControllerDeploymentState,
+    HierarchyControllerState,
+    HierarchyControllerVersion,
+    InstallError,
+    MembershipSpec,
+    MembershipState,
+    OperatorState,
+    PolicyController,
+    PolicyControllerState,
+    PolicyControllerVersion,
+    SyncError,
+    SyncState,
+)
 
 __all__ = (
     "ConfigSync",
