@@ -13,8 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from __future__ import annotations
 
+from typing import MutableMapping, MutableSequence
+
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.gkehub.multiclusteringress.v1",
@@ -35,7 +38,7 @@ class FeatureSpec(proto.Message):
             ``projects/foo-proj/locations/global/memberships/bar``
     """
 
-    config_membership = proto.Field(
+    config_membership: str = proto.Field(
         proto.STRING,
         number=1,
     )
