@@ -16,19 +16,31 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.gkehub_v1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -36,16 +48,17 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gkehub_v1.services.gke_hub import pagers
-from google.cloud.gkehub_v1.types import feature
-from google.cloud.gkehub_v1.types import membership
-from google.cloud.gkehub_v1.types import service
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import GkeHubTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.gkehub_v1.services.gke_hub import pagers
+from google.cloud.gkehub_v1.types import feature, membership, service
+
+from .transports.base import DEFAULT_CLIENT_INFO, GkeHubTransport
 from .transports.grpc import GkeHubGrpcTransport
 from .transports.grpc_asyncio import GkeHubGrpcAsyncIOTransport
+from .transports.rest import GkeHubRestTransport
 
 
 class GkeHubClientMeta(type):
@@ -59,10 +72,11 @@ class GkeHubClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[GkeHubTransport]]
     _transport_registry["grpc"] = GkeHubGrpcTransport
     _transport_registry["grpc_asyncio"] = GkeHubGrpcAsyncIOTransport
+    _transport_registry["rest"] = GkeHubRestTransport
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[GkeHubTransport]:
         """Returns an appropriate transport class.
 
@@ -320,7 +334,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -375,8 +389,8 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, GkeHubTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, GkeHubTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the gke hub client.
@@ -390,7 +404,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
             transport (Union[str, GkeHubTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -420,6 +434,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -472,11 +487,11 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def list_memberships(
         self,
-        request: Union[service.ListMembershipsRequest, dict] = None,
+        request: Optional[Union[service.ListMembershipsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMembershipsPager:
         r"""Lists Memberships in a given project and location.
@@ -510,8 +525,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.ListMembershipsRequest, dict]):
-                The request object. Request message for
-                `GkeHub.ListMemberships` method.
+                The request object. Request message for ``GkeHub.ListMemberships`` method.
             parent (str):
                 Required. The parent (project and location) where the
                 Memberships will be listed. Specified in the format
@@ -587,11 +601,11 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def list_features(
         self,
-        request: Union[service.ListFeaturesRequest, dict] = None,
+        request: Optional[Union[service.ListFeaturesRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListFeaturesPager:
         r"""Lists Features in a given project and location.
@@ -624,8 +638,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.ListFeaturesRequest, dict]):
-                The request object. Request message for
-                `GkeHub.ListFeatures` method.
+                The request object. Request message for ``GkeHub.ListFeatures`` method.
             parent (str):
                 Required. The parent (project and location) where the
                 Features will be listed. Specified in the format
@@ -701,11 +714,11 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def get_membership(
         self,
-        request: Union[service.GetMembershipRequest, dict] = None,
+        request: Optional[Union[service.GetMembershipRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.Membership:
         r"""Gets the details of a Membership.
@@ -738,8 +751,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.GetMembershipRequest, dict]):
-                The request object. Request message for
-                `GkeHub.GetMembership` method.
+                The request object. Request message for ``GkeHub.GetMembership`` method.
             name (str):
                 Required. The Membership resource name in the format
                 ``projects/*/locations/*/memberships/*``.
@@ -803,11 +815,11 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def get_feature(
         self,
-        request: Union[service.GetFeatureRequest, dict] = None,
+        request: Optional[Union[service.GetFeatureRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> feature.Feature:
         r"""Gets details of a single Feature.
@@ -839,8 +851,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.GetFeatureRequest, dict]):
-                The request object. Request message for
-                `GkeHub.GetFeature` method.
+                The request object. Request message for ``GkeHub.GetFeature`` method.
             name (str):
                 Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``
@@ -904,13 +915,13 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def create_membership(
         self,
-        request: Union[service.CreateMembershipRequest, dict] = None,
+        request: Optional[Union[service.CreateMembershipRequest, dict]] = None,
         *,
-        parent: str = None,
-        resource: membership.Membership = None,
-        membership_id: str = None,
+        parent: Optional[str] = None,
+        resource: Optional[membership.Membership] = None,
+        membership_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new Membership.
@@ -952,8 +963,8 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.CreateMembershipRequest, dict]):
-                The request object. Request message for the
-                `GkeHub.CreateMembership` method.
+                The request object. Request message for the ``GkeHub.CreateMembership``
+                method.
             parent (str):
                 Required. The parent (project and location) where the
                 Memberships will be created. Specified in the format
@@ -1055,13 +1066,13 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def create_feature(
         self,
-        request: Union[service.CreateFeatureRequest, dict] = None,
+        request: Optional[Union[service.CreateFeatureRequest, dict]] = None,
         *,
-        parent: str = None,
-        resource: feature.Feature = None,
-        feature_id: str = None,
+        parent: Optional[str] = None,
+        resource: Optional[feature.Feature] = None,
+        feature_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Adds a new Feature.
@@ -1097,8 +1108,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.CreateFeatureRequest, dict]):
-                The request object. Request message for the
-                `GkeHub.CreateFeature` method.
+                The request object. Request message for the ``GkeHub.CreateFeature`` method.
             parent (str):
                 Required. The parent (project and location) where the
                 Feature will be created. Specified in the format
@@ -1188,11 +1198,11 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def delete_membership(
         self,
-        request: Union[service.DeleteMembershipRequest, dict] = None,
+        request: Optional[Union[service.DeleteMembershipRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Removes a Membership.
@@ -1234,8 +1244,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.DeleteMembershipRequest, dict]):
-                The request object. Request message for
-                `GkeHub.DeleteMembership` method.
+                The request object. Request message for ``GkeHub.DeleteMembership`` method.
             name (str):
                 Required. The Membership resource name in the format
                 ``projects/*/locations/*/memberships/*``.
@@ -1317,11 +1326,11 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def delete_feature(
         self,
-        request: Union[service.DeleteFeatureRequest, dict] = None,
+        request: Optional[Union[service.DeleteFeatureRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Removes a Feature.
@@ -1357,8 +1366,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.DeleteFeatureRequest, dict]):
-                The request object. Request message for
-                `GkeHub.DeleteFeature` method.
+                The request object. Request message for ``GkeHub.DeleteFeature`` method.
             name (str):
                 Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``.
@@ -1440,13 +1448,13 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def update_membership(
         self,
-        request: Union[service.UpdateMembershipRequest, dict] = None,
+        request: Optional[Union[service.UpdateMembershipRequest, dict]] = None,
         *,
-        name: str = None,
-        resource: membership.Membership = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        name: Optional[str] = None,
+        resource: Optional[membership.Membership] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates an existing Membership.
@@ -1483,8 +1491,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.UpdateMembershipRequest, dict]):
-                The request object. Request message for
-                `GkeHub.UpdateMembership` method.
+                The request object. Request message for ``GkeHub.UpdateMembership`` method.
             name (str):
                 Required. The Membership resource name in the format
                 ``projects/*/locations/*/memberships/*``.
@@ -1582,13 +1589,13 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def update_feature(
         self,
-        request: Union[service.UpdateFeatureRequest, dict] = None,
+        request: Optional[Union[service.UpdateFeatureRequest, dict]] = None,
         *,
-        name: str = None,
-        resource: feature.Feature = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        name: Optional[str] = None,
+        resource: Optional[feature.Feature] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates an existing Feature.
@@ -1624,8 +1631,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.UpdateFeatureRequest, dict]):
-                The request object. Request message for
-                `GkeHub.UpdateFeature` method.
+                The request object. Request message for ``GkeHub.UpdateFeature`` method.
             name (str):
                 Required. The Feature resource name in the format
                 ``projects/*/locations/*/features/*``.
@@ -1723,10 +1729,10 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
     def generate_connect_manifest(
         self,
-        request: Union[service.GenerateConnectManifestRequest, dict] = None,
+        request: Optional[Union[service.GenerateConnectManifestRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.GenerateConnectManifestResponse:
         r"""Generates the manifest for deployment of the GKE connect agent.
@@ -1762,9 +1768,8 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
 
         Args:
             request (Union[google.cloud.gkehub_v1.types.GenerateConnectManifestRequest, dict]):
-                The request object. Request message for
-                `GkeHub.GenerateConnectManifest` method.
-                .
+                The request object. Request message for ``GkeHub.GenerateConnectManifest``
+                method. .
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1809,7 +1814,7 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "GkeHubClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -1823,14 +1828,9 @@ class GkeHubClient(metaclass=GkeHubClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-gke-hub",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GkeHubClient",)
