@@ -16,19 +16,31 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.gkehub_v1beta1 import gapic_version as package_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
@@ -36,8 +48,6 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gkehub_v1beta1.services.gke_hub_membership_service import pagers
-from google.cloud.gkehub_v1beta1.types import membership
 from google.cloud.location import locations_pb2  # type: ignore
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
@@ -46,9 +56,14 @@ from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
-from .transports.base import GkeHubMembershipServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.gkehub_v1beta1.services.gke_hub_membership_service import pagers
+from google.cloud.gkehub_v1beta1.types import membership
+
+from .transports.base import DEFAULT_CLIENT_INFO, GkeHubMembershipServiceTransport
 from .transports.grpc import GkeHubMembershipServiceGrpcTransport
 from .transports.grpc_asyncio import GkeHubMembershipServiceGrpcAsyncIOTransport
+from .transports.rest import GkeHubMembershipServiceRestTransport
 
 
 class GkeHubMembershipServiceClientMeta(type):
@@ -64,10 +79,11 @@ class GkeHubMembershipServiceClientMeta(type):
     )  # type: Dict[str, Type[GkeHubMembershipServiceTransport]]
     _transport_registry["grpc"] = GkeHubMembershipServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = GkeHubMembershipServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = GkeHubMembershipServiceRestTransport
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[GkeHubMembershipServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -298,7 +314,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -353,8 +369,8 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, GkeHubMembershipServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, GkeHubMembershipServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the gke hub membership service client.
@@ -368,7 +384,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
             transport (Union[str, GkeHubMembershipServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -398,6 +414,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -450,11 +467,11 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def list_memberships(
         self,
-        request: Union[membership.ListMembershipsRequest, dict] = None,
+        request: Optional[Union[membership.ListMembershipsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListMembershipsPager:
         r"""Lists Memberships in a given project and location.
@@ -489,7 +506,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         Args:
             request (Union[google.cloud.gkehub_v1beta1.types.ListMembershipsRequest, dict]):
                 The request object. Request message for
-                `GkeHubMembershipService.ListMemberships` method.
+                ``GkeHubMembershipService.ListMemberships`` method.
             parent (str):
                 Required. The parent (project and location) where the
                 Memberships will be listed. Specified in the format
@@ -566,11 +583,11 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def get_membership(
         self,
-        request: Union[membership.GetMembershipRequest, dict] = None,
+        request: Optional[Union[membership.GetMembershipRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.Membership:
         r"""Gets the details of a Membership.
@@ -604,7 +621,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         Args:
             request (Union[google.cloud.gkehub_v1beta1.types.GetMembershipRequest, dict]):
                 The request object. Request message for
-                `GkeHubMembershipService.GetMembership` method.
+                ``GkeHubMembershipService.GetMembership`` method.
             name (str):
                 Required. The Membership resource name in the format
                 ``projects/*/locations/*/memberships/*``.
@@ -668,13 +685,13 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def create_membership(
         self,
-        request: Union[membership.CreateMembershipRequest, dict] = None,
+        request: Optional[Union[membership.CreateMembershipRequest, dict]] = None,
         *,
-        parent: str = None,
-        resource: membership.Membership = None,
-        membership_id: str = None,
+        parent: Optional[str] = None,
+        resource: Optional[membership.Membership] = None,
+        membership_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Creates a new Membership.
@@ -717,7 +734,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         Args:
             request (Union[google.cloud.gkehub_v1beta1.types.CreateMembershipRequest, dict]):
                 The request object. Request message for the
-                `GkeHubMembershipService.CreateMembership` method.
+                ``GkeHubMembershipService.CreateMembership`` method.
             parent (str):
                 Required. The parent (project and location) where the
                 Memberships will be created. Specified in the format
@@ -819,11 +836,11 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def delete_membership(
         self,
-        request: Union[membership.DeleteMembershipRequest, dict] = None,
+        request: Optional[Union[membership.DeleteMembershipRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Removes a Membership.
@@ -866,7 +883,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         Args:
             request (Union[google.cloud.gkehub_v1beta1.types.DeleteMembershipRequest, dict]):
                 The request object. Request message for
-                `GkeHubMembershipService.DeleteMembership` method.
+                ``GkeHubMembershipService.DeleteMembership`` method.
             name (str):
                 Required. The Membership resource name in the format
                 ``projects/*/locations/*/memberships/*``.
@@ -948,13 +965,13 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def update_membership(
         self,
-        request: Union[membership.UpdateMembershipRequest, dict] = None,
+        request: Optional[Union[membership.UpdateMembershipRequest, dict]] = None,
         *,
-        name: str = None,
-        resource: membership.Membership = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        name: Optional[str] = None,
+        resource: Optional[membership.Membership] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
         r"""Updates an existing Membership.
@@ -992,7 +1009,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         Args:
             request (Union[google.cloud.gkehub_v1beta1.types.UpdateMembershipRequest, dict]):
                 The request object. Request message for
-                `GkeHubMembershipService.UpdateMembership` method.
+                ``GkeHubMembershipService.UpdateMembership`` method.
             name (str):
                 Required. The membership resource name in the format:
                 ``projects/[project_id]/locations/global/memberships/[membership_id]``
@@ -1093,10 +1110,12 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def generate_connect_manifest(
         self,
-        request: Union[membership.GenerateConnectManifestRequest, dict] = None,
+        request: Optional[
+            Union[membership.GenerateConnectManifestRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.GenerateConnectManifestResponse:
         r"""Generates the manifest for deployment of the GKE connect agent.
@@ -1133,7 +1152,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         Args:
             request (Union[google.cloud.gkehub_v1beta1.types.GenerateConnectManifestRequest, dict]):
                 The request object. Request message for
-                `GkeHubMembershipService.GenerateConnectManifest`
+                ``GkeHubMembershipService.GenerateConnectManifest``
                 method. .
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -1181,10 +1200,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def validate_exclusivity(
         self,
-        request: Union[membership.ValidateExclusivityRequest, dict] = None,
+        request: Optional[Union[membership.ValidateExclusivityRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.ValidateExclusivityResponse:
         r"""ValidateExclusivity validates the state of
@@ -1221,7 +1240,8 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         Args:
             request (Union[google.cloud.gkehub_v1beta1.types.ValidateExclusivityRequest, dict]):
                 The request object. The request to validate the existing
-                state of the membership CR in the cluster.
+                state of the membership CR in the
+                cluster.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1265,10 +1285,12 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def generate_exclusivity_manifest(
         self,
-        request: Union[membership.GenerateExclusivityManifestRequest, dict] = None,
+        request: Optional[
+            Union[membership.GenerateExclusivityManifestRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> membership.GenerateExclusivityManifestResponse:
         r"""GenerateExclusivityManifest generates the manifests
@@ -1314,8 +1336,8 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
         Args:
             request (Union[google.cloud.gkehub_v1beta1.types.GenerateExclusivityManifestRequest, dict]):
-                The request object. The request to generate the
-                manifests for exclusivity artifacts.
+                The request object. The request to generate the manifests
+                for exclusivity artifacts.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1360,7 +1382,7 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "GkeHubMembershipServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
@@ -1375,10 +1397,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -1429,10 +1451,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -1483,10 +1505,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def delete_operation(
         self,
-        request: operations_pb2.DeleteOperationRequest = None,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a long-running operation.
@@ -1538,10 +1560,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def cancel_operation(
         self,
-        request: operations_pb2.CancelOperationRequest = None,
+        request: Optional[operations_pb2.CancelOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Starts asynchronous cancellation on a long-running operation.
@@ -1592,10 +1614,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def set_iam_policy(
         self,
-        request: iam_policy_pb2.SetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.SetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the IAM access control policy on the specified function.
@@ -1712,10 +1734,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def get_iam_policy(
         self,
-        request: iam_policy_pb2.GetIamPolicyRequest = None,
+        request: Optional[iam_policy_pb2.GetIamPolicyRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the IAM access control policy for a function.
@@ -1833,10 +1855,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def test_iam_permissions(
         self,
-        request: iam_policy_pb2.TestIamPermissionsRequest = None,
+        request: Optional[iam_policy_pb2.TestIamPermissionsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Tests the specified IAM permissions against the IAM access control
@@ -1892,10 +1914,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def get_location(
         self,
-        request: locations_pb2.GetLocationRequest = None,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.Location:
         r"""Gets information about a location.
@@ -1946,10 +1968,10 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
 
     def list_locations(
         self,
-        request: locations_pb2.ListLocationsRequest = None,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.ListLocationsResponse:
         r"""Lists information about the supported locations for this service.
@@ -1999,14 +2021,9 @@ class GkeHubMembershipServiceClient(metaclass=GkeHubMembershipServiceClientMeta)
         return response
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-gke-hub",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("GkeHubMembershipServiceClient",)
