@@ -13,12 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.gkehub.v1beta1",
@@ -79,7 +81,7 @@ class Membership(proto.Message):
             Which can be expressed as the regex:
             ``[a-z0-9]([-a-z0-9]*[a-z0-9])?``, with a maximum length of
             63 characters.
-        labels (Mapping[str, str]):
+        labels (MutableMapping[str, str]):
             Optional. GCP labels for this membership.
         description (str):
             Optional. Description of this membership, limited to 63
@@ -142,69 +144,82 @@ class Membership(proto.Message):
         Each GKE distribution (on-GCP, on-Prem, on-X,...) will set this
         field automatically, but Attached Clusters customers should
         specify a type during registration.
+
+        Values:
+            INFRASTRUCTURE_TYPE_UNSPECIFIED (0):
+                No type was specified. Some Hub functionality
+                may require a type be specified, and will not
+                support Memberships with this value.
+            ON_PREM (1):
+                Private infrastructure that is owned or
+                operated by customer. This includes GKE
+                distributions such as GKE-OnPrem and
+                GKE-OnBareMetal.
+            MULTI_CLOUD (2):
+                Public cloud infrastructure.
         """
         INFRASTRUCTURE_TYPE_UNSPECIFIED = 0
         ON_PREM = 1
         MULTI_CLOUD = 2
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    labels = proto.MapField(
+    labels: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=2,
     )
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    endpoint = proto.Field(
+    endpoint: "MembershipEndpoint" = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="type",
         message="MembershipEndpoint",
     )
-    state = proto.Field(
+    state: "MembershipState" = proto.Field(
         proto.MESSAGE,
         number=5,
         message="MembershipState",
     )
-    authority = proto.Field(
+    authority: "Authority" = proto.Field(
         proto.MESSAGE,
         number=9,
         message="Authority",
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=6,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=7,
         message=timestamp_pb2.Timestamp,
     )
-    delete_time = proto.Field(
+    delete_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=8,
         message=timestamp_pb2.Timestamp,
     )
-    external_id = proto.Field(
+    external_id: str = proto.Field(
         proto.STRING,
         number=10,
     )
-    last_connection_time = proto.Field(
+    last_connection_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=11,
         message=timestamp_pb2.Timestamp,
     )
-    unique_id = proto.Field(
+    unique_id: str = proto.Field(
         proto.STRING,
         number=12,
     )
-    infrastructure_type = proto.Field(
+    infrastructure_type: InfrastructureType = proto.Field(
         proto.ENUM,
         number=13,
         enum=InfrastructureType,
@@ -266,42 +281,42 @@ class MembershipEndpoint(proto.Message):
                Features.
     """
 
-    gke_cluster = proto.Field(
+    gke_cluster: "GkeCluster" = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="type",
         message="GkeCluster",
     )
-    on_prem_cluster = proto.Field(
+    on_prem_cluster: "OnPremCluster" = proto.Field(
         proto.MESSAGE,
         number=7,
         oneof="type",
         message="OnPremCluster",
     )
-    multi_cloud_cluster = proto.Field(
+    multi_cloud_cluster: "MultiCloudCluster" = proto.Field(
         proto.MESSAGE,
         number=8,
         oneof="type",
         message="MultiCloudCluster",
     )
-    edge_cluster = proto.Field(
+    edge_cluster: "EdgeCluster" = proto.Field(
         proto.MESSAGE,
         number=9,
         oneof="type",
         message="EdgeCluster",
     )
-    appliance_cluster = proto.Field(
+    appliance_cluster: "ApplianceCluster" = proto.Field(
         proto.MESSAGE,
         number=10,
         oneof="type",
         message="ApplianceCluster",
     )
-    kubernetes_metadata = proto.Field(
+    kubernetes_metadata: "KubernetesMetadata" = proto.Field(
         proto.MESSAGE,
         number=5,
         message="KubernetesMetadata",
     )
-    kubernetes_resource = proto.Field(
+    kubernetes_resource: "KubernetesResource" = proto.Field(
         proto.MESSAGE,
         number=6,
         message="KubernetesResource",
@@ -325,7 +340,7 @@ class KubernetesResource(proto.Message):
             if none exists. The CR manifest is used to
             validate the cluster has not been registered
             with another Membership.
-        membership_resources (Sequence[google.cloud.gkehub_v1beta1.types.ResourceManifest]):
+        membership_resources (MutableSequence[google.cloud.gkehub_v1beta1.types.ResourceManifest]):
             Output only. Additional Kubernetes resources
             that need to be applied to the cluster after
             Membership creation, and after every update.
@@ -337,7 +352,7 @@ class KubernetesResource(proto.Message):
             requests. To get the resource manifest after the
             initial registration, the caller should make a
             UpdateMembership call with an empty field mask.
-        connect_resources (Sequence[google.cloud.gkehub_v1beta1.types.ResourceManifest]):
+        connect_resources (MutableSequence[google.cloud.gkehub_v1beta1.types.ResourceManifest]):
             Output only. The Kubernetes resources for
             installing the GKE Connect agent
             This field is only populated in the Membership
@@ -353,21 +368,21 @@ class KubernetesResource(proto.Message):
             generation.
     """
 
-    membership_cr_manifest = proto.Field(
+    membership_cr_manifest: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    membership_resources = proto.RepeatedField(
+    membership_resources: MutableSequence["ResourceManifest"] = proto.RepeatedField(
         proto.MESSAGE,
         number=2,
         message="ResourceManifest",
     )
-    connect_resources = proto.RepeatedField(
+    connect_resources: MutableSequence["ResourceManifest"] = proto.RepeatedField(
         proto.MESSAGE,
         number=3,
         message="ResourceManifest",
     )
-    resource_options = proto.Field(
+    resource_options: "ResourceOptions" = proto.Field(
         proto.MESSAGE,
         number=4,
         message="ResourceOptions",
@@ -396,15 +411,15 @@ class ResourceOptions(proto.Message):
             ``apiextensions/v1beta1`` or\ ``apiextensions/v1``.
     """
 
-    connect_version = proto.Field(
+    connect_version: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    v1beta1_crd = proto.Field(
+    v1beta1_crd: bool = proto.Field(
         proto.BOOL,
         number=2,
     )
-    k8s_version = proto.Field(
+    k8s_version: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -426,11 +441,11 @@ class ResourceManifest(proto.Message):
             resource in a cluster.
     """
 
-    manifest = proto.Field(
+    manifest: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    cluster_scoped = proto.Field(
+    cluster_scoped: bool = proto.Field(
         proto.BOOL,
         number=2,
     )
@@ -450,11 +465,11 @@ class GkeCluster(proto.Message):
             the GKE cluster no longer exists in the GKE Control Plane.
     """
 
-    resource_link = proto.Field(
+    resource_link: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    cluster_missing = proto.Field(
+    cluster_missing: bool = proto.Field(
         proto.BOOL,
         number=3,
     )
@@ -482,26 +497,40 @@ class OnPremCluster(proto.Message):
     """
 
     class ClusterType(proto.Enum):
-        r"""ClusterType describes on prem cluster's type."""
+        r"""ClusterType describes on prem cluster's type.
+
+        Values:
+            CLUSTERTYPE_UNSPECIFIED (0):
+                The ClusterType is not set.
+            BOOTSTRAP (1):
+                The ClusterType is bootstrap cluster.
+            HYBRID (2):
+                The ClusterType is baremetal hybrid cluster.
+            STANDALONE (3):
+                The ClusterType is baremetal standalone
+                cluster.
+            USER (4):
+                The ClusterType is user cluster.
+        """
         CLUSTERTYPE_UNSPECIFIED = 0
         BOOTSTRAP = 1
         HYBRID = 2
         STANDALONE = 3
         USER = 4
 
-    resource_link = proto.Field(
+    resource_link: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    cluster_missing = proto.Field(
+    cluster_missing: bool = proto.Field(
         proto.BOOL,
         number=2,
     )
-    admin_cluster = proto.Field(
+    admin_cluster: bool = proto.Field(
         proto.BOOL,
         number=3,
     )
-    cluster_type = proto.Field(
+    cluster_type: ClusterType = proto.Field(
         proto.ENUM,
         number=4,
         enum=ClusterType,
@@ -525,11 +554,11 @@ class MultiCloudCluster(proto.Message):
             Multi-Cloud cluster no longer exists.
     """
 
-    resource_link = proto.Field(
+    resource_link: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    cluster_missing = proto.Field(
+    cluster_missing: bool = proto.Field(
         proto.BOOL,
         number=2,
     )
@@ -547,7 +576,7 @@ class EdgeCluster(proto.Message):
             //edgecontainer.googleapis.com/projects/my-project/locations/us-west1-a/clusters/my-cluster
     """
 
-    resource_link = proto.Field(
+    resource_link: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -565,7 +594,7 @@ class ApplianceCluster(proto.Message):
             //transferappliance.googleapis.com/projects/my-project/locations/us-west1-a/appliances/my-appliance
     """
 
-    resource_link = proto.Field(
+    resource_link: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -602,27 +631,27 @@ class KubernetesMetadata(proto.Message):
             updated internally for API consumers.
     """
 
-    kubernetes_api_server_version = proto.Field(
+    kubernetes_api_server_version: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    node_provider_id = proto.Field(
+    node_provider_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    node_count = proto.Field(
+    node_count: int = proto.Field(
         proto.INT32,
         number=3,
     )
-    vcpu_count = proto.Field(
+    vcpu_count: int = proto.Field(
         proto.INT32,
         number=4,
     )
-    memory_mb = proto.Field(
+    memory_mb: int = proto.Field(
         proto.INT32,
         number=5,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=100,
         message=timestamp_pb2.Timestamp,
@@ -671,19 +700,19 @@ class Authority(proto.Message):
             using this field.
     """
 
-    issuer = proto.Field(
+    issuer: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    workload_identity_pool = proto.Field(
+    workload_identity_pool: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    identity_provider = proto.Field(
+    identity_provider: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    oidc_jwks = proto.Field(
+    oidc_jwks: bytes = proto.Field(
         proto.BYTES,
         number=4,
     )
@@ -703,7 +732,23 @@ class MembershipState(proto.Message):
     """
 
     class Code(proto.Enum):
-        r"""Code describes the state of a Membership resource."""
+        r"""Code describes the state of a Membership resource.
+
+        Values:
+            CODE_UNSPECIFIED (0):
+                The code is not set.
+            CREATING (1):
+                The cluster is being registered.
+            READY (2):
+                The cluster is registered.
+            DELETING (3):
+                The cluster is being unregistered.
+            UPDATING (4):
+                The Membership is being updated.
+            SERVICE_UPDATING (5):
+                The Membership is being updated by the Hub
+                Service.
+        """
         CODE_UNSPECIFIED = 0
         CREATING = 1
         READY = 2
@@ -711,16 +756,16 @@ class MembershipState(proto.Message):
         UPDATING = 4
         SERVICE_UPDATING = 5
 
-    code = proto.Field(
+    code: Code = proto.Field(
         proto.ENUM,
         number=1,
         enum=Code,
     )
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
@@ -775,23 +820,23 @@ class ListMembershipsRequest(proto.Message):
             https://google.aip.dev/132#ordering.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    filter = proto.Field(
+    filter: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    order_by = proto.Field(
+    order_by: str = proto.Field(
         proto.STRING,
         number=5,
     )
@@ -802,13 +847,13 @@ class ListMembershipsResponse(proto.Message):
     method.
 
     Attributes:
-        resources (Sequence[google.cloud.gkehub_v1beta1.types.Membership]):
+        resources (MutableSequence[google.cloud.gkehub_v1beta1.types.Membership]):
             The list of matching Memberships.
         next_page_token (str):
             A token to request the next page of resources from the
             ``ListMemberships`` method. The value of an empty string
             means that there are no more resources to return.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             List of locations that could not be reached
             while fetching this list.
     """
@@ -817,16 +862,16 @@ class ListMembershipsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    resources = proto.RepeatedField(
+    resources: MutableSequence["Membership"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="Membership",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    unreachable = proto.RepeatedField(
+    unreachable: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -842,7 +887,7 @@ class GetMembershipRequest(proto.Message):
             ``projects/*/locations/*/memberships/*``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -892,20 +937,20 @@ class CreateMembershipRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    membership_id = proto.Field(
+    membership_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    resource = proto.Field(
+    resource: "Membership" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="Membership",
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -939,11 +984,11 @@ class DeleteMembershipRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -989,21 +1034,21 @@ class UpdateMembershipRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=2,
         message=field_mask_pb2.FieldMask,
     )
-    resource = proto.Field(
+    resource: "Membership" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="Membership",
     )
-    request_id = proto.Field(
+    request_id: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -1036,28 +1081,28 @@ class GenerateConnectManifestRequest(proto.Message):
             the registry, if not public.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    connect_agent = proto.Field(
+    connect_agent: "ConnectAgent" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="ConnectAgent",
     )
-    version = proto.Field(
+    version: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    is_upgrade = proto.Field(
+    is_upgrade: bool = proto.Field(
         proto.BOOL,
         number=4,
     )
-    registry = proto.Field(
+    registry: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    image_pull_secret_content = proto.Field(
+    image_pull_secret_content: bytes = proto.Field(
         proto.BYTES,
         number=6,
     )
@@ -1068,13 +1113,13 @@ class GenerateConnectManifestResponse(proto.Message):
     for installing/upgrading a Connect agent.
 
     Attributes:
-        manifest (Sequence[google.cloud.gkehub_v1beta1.types.ConnectAgentResource]):
+        manifest (MutableSequence[google.cloud.gkehub_v1beta1.types.ConnectAgentResource]):
             The ordered list of Kubernetes resources that
             need to be applied to the cluster for GKE
             Connect agent installation/upgrade.
     """
 
-    manifest = proto.RepeatedField(
+    manifest: MutableSequence["ConnectAgentResource"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="ConnectAgentResource",
@@ -1092,12 +1137,12 @@ class ConnectAgentResource(proto.Message):
             YAML manifest of the resource.
     """
 
-    type_ = proto.Field(
+    type_: "TypeMeta" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="TypeMeta",
     )
-    manifest = proto.Field(
+    manifest: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -1114,11 +1159,11 @@ class TypeMeta(proto.Message):
             APIVersion of the resource (e.g. v1).
     """
 
-    kind = proto.Field(
+    kind: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    api_version = proto.Field(
+    api_version: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -1146,15 +1191,15 @@ class ConnectAgent(proto.Message):
             must be granted with an additional IAM binding.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    proxy = proto.Field(
+    proxy: bytes = proto.Field(
         proto.BYTES,
         number=2,
     )
-    namespace = proto.Field(
+    namespace: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -1179,15 +1224,15 @@ class ValidateExclusivityRequest(proto.Message):
             CreateMembership call with the same name.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    cr_manifest = proto.Field(
+    cr_manifest: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    intended_membership = proto.Field(
+    intended_membership: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -1209,7 +1254,7 @@ class ValidateExclusivityResponse(proto.Message):
                more information.
     """
 
-    status = proto.Field(
+    status: status_pb2.Status = proto.Field(
         proto.MESSAGE,
         number=1,
         message=status_pb2.Status,
@@ -1234,15 +1279,15 @@ class GenerateExclusivityManifestRequest(proto.Message):
             the resource does not exist.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    crd_manifest = proto.Field(
+    crd_manifest: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    cr_manifest = proto.Field(
+    cr_manifest: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -1264,11 +1309,11 @@ class GenerateExclusivityManifestResponse(proto.Message):
             Empty if no update needs to be applied.
     """
 
-    crd_manifest = proto.Field(
+    crd_manifest: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    cr_manifest = proto.Field(
+    cr_manifest: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -1304,33 +1349,33 @@ class OperationMetadata(proto.Message):
             operation.
     """
 
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=1,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    target = proto.Field(
+    target: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    verb = proto.Field(
+    verb: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    status_detail = proto.Field(
+    status_detail: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    cancel_requested = proto.Field(
+    cancel_requested: bool = proto.Field(
         proto.BOOL,
         number=6,
     )
-    api_version = proto.Field(
+    api_version: str = proto.Field(
         proto.STRING,
         number=7,
     )
